// Read a salary database into the sketch and report on the
// ten highest-paid employees listed.

float processDollars( String val )
{
  // Break the dollar amount apart at all delimiters
  String[] digs = splitTokens( val, ",.$" );
  // Figure out the cents
  return float( join( digs, "" ) ) / 100.0;
}

void setup()
{
  Table table = new Table();
  table.addColumn( "Institution" );
  table.addColumn( "Last name" );
  table.addColumn( "First name" );
  table.addColumn( "Position" );
  table.addColumn( "Salary", Table.FLOAT );
  
  String[] lines = loadStrings( "salaries.txt" );
  for( int idx = 0; idx < lines.length; ++idx ) {
    String[] fields = splitTokens( lines[idx], "\t" );
    TableRow row = table.addRow();
    row.setString( "Institution", fields[0] );
    row.setString( "Last name", fields[1] );
    row.setString( "First name", fields[2] );
    row.setString( "Position", fields[3] );
    row.setFloat( "Salary", 
      processDollars( fields[4] ) + 
      processDollars( fields[5] ) );
      if( fields[1].equals( "CHAKMA" ) ) {
        println( processDollars( fields[4] ) );
        println( processDollars( fields[5] ) );
      }
  }
  
  // Stupidly, this method exists in the Table class
  // but it isn't documented on the Processing website.
  // It does what you might expect from using a spreadsheet
  // program -- it sorts all the rows in the table, using
  // Salaries as the key.
  table.sort( "Salary" );
  
  size( 500, 760 );
  background( 255 );
  PFont fnt = createFont( "Helvetica", 16 );
  textFont( fnt );
  fill( 0 );
  int y = 20;
  
  for( int idx = 0; idx < 10; ++idx ) {
    int r = table.getRowCount() - 10 + idx;
    TableRow row = table.getRow( r );
    text( row.getString( "First name" ) + " " + 
      row.getString( "Last name" ), 5, y );
    y += 20;
    text( row.getString( "Position" ) + ", " + 
      row.getString( "Institution" ), 25, y );
    y += 20;
    text( row.getFloat( "Salary" ), 25, y );
    y += 35;
  }
}
