// A searchable salary table where you can type the prefix
// to a last name and the sketch will "Autocomplete", showing
// you all people in the list whose last names start with that
// prefix.

Table table;
String prefix;

float processDollars( String val )
{
  // Break the dollar amount apart at all delimiters
  String[] digs = splitTokens( val, ",.$" );
  // Figure out the cents
  return float( join( digs, "" ) ) / 100.0;
}

void setup()
{
  size( 800, 600 );
  noStroke();
  
  table = loadTable( "salaries.txt", "header, tsv" );

  for( int idx = 0; idx < table.getRowCount(); ++idx ) {
    table.setFloat( idx, "Salary", 
      processDollars( table.getString( idx, "Salary" ) ) +
      processDollars( table.getString( idx, "Benefits" ) ) );
  }
  
  table.removeColumn( "Benefits" );
  
  textFont( createFont( "Helvetica", 18 ) );
  prefix = "";
}

void draw()
{
  background( 255 );
  fill( 0 );
  if( prefix.length() > 0 ) {
    text( prefix, 10, 24 );
    int y = 56;
    for( int idx = 0; idx < table.getRowCount(); ++idx ) {
      String name = table.getString( idx, "Last name" );
      if( name.startsWith( prefix.toUpperCase() ) ) {
        String msg = table.getString( idx, "First name" )
          + " " + table.getString( idx, "Last name" )
          + " (" + table.getString( idx, "Institution" ) 
          + "): " + table.getFloat( idx, "Salary" );
        text( msg, 10, y );
        y += 25;
        
        if( y > height + 25 ) {
          break;
        }
      }  
    }
  }
}

void keyPressed()
{
  if( keyCode == BACKSPACE ) {
    if( prefix.length() > 0 ) {
      prefix = prefix.substring( 0, prefix.length() - 1 );
    } 
  } else if( Character.isLetter( key ) ) {
    prefix = prefix + key;
  }
}
