// An earlier approach to loading in the salary file, which
// corresponds to some of the things I talked about in Module 07.
// Then, I said that one way to maintain a table of information is
// as an array of class instances, where each instance represents
// one row of the table.  I'm not including any discussion of this
// in the Module 10 notes, but I thought I'd preserve it in case
// anyone is interested.

class Employee
  implements Comparable<Employee>
{
  String institution;
  String lastname;
  String firstname;
  String position;
  float salary;

  Employee( String[] toks )
  {
    institution = toks[0];
    lastname = toks[1];
    firstname = toks[2];
    position = toks[3];
    // Just add together salary and benefits.  Let's
    // not split hairs here.
    salary = processDollars( toks[4] ) + processDollars( toks[5] );
  }
  
  // If I implement this method, then I'll be able
  // to use built-in Java features to sort an array
  // of Employee instances.
  int compareTo( Employee other )
  {
    if( salary < other.salary ) {
      return -1;
    } else if( salary > other.salary ) {
      return 1;
    } else {
      return 0;
    }
  }
}

float processDollars( String val )
{
  // Break the dollar amount apart at all delimiters
  String[] digs = splitTokens( val, ",.$" );
  // Figure out the cents
  return float( join( digs, "" ) ) / 100.0;
}

void setup()
{
  Employee[] emps = new Employee[0];

  String[] lines = loadStrings( "salaries.txt" );
  for ( int idx = 0; idx < lines.length; ++idx ) {
    String[] toks = splitTokens( lines[idx], "\t" );
    Employee emp = new Employee( toks );
    emps = (Employee[])append( emps, emp );
  }
  
  // Use a handy Java function that can sort anything,
  // as long as objects know how to compare themselves
  // to other objects to find out who's bigger.
  java.util.Arrays.sort( emps );
  
  size( 500, 760 );
  background( 255 );
  PFont fnt = createFont( "Helvetica", 16 );
  textFont( fnt );
  fill( 0 );
  int y = 20;
  
  for( int idx = 0; idx < 10; ++idx ) {
    int r = emps.length - 10 + idx;
    Employee emp = emps[r];
    text( emp.firstname + " " + emp.lastname, 5, y );
    y += 20;
    text( emp.position + ", " + emp.institution, 25, y );
    y += 20;
    text( emp.salary, 25, y );
    y += 35;
  }
}

