// Visualize salary data as a histogram.

float processDollars( String val )
{
  // Break the dollar amount apart at all delimiters
  String[] digs = splitTokens( val, ",.$" );
  // Figure out the cents
  return float( join( digs, "" ) ) / 100.0;
}

void setup()
{
  size( 800, 400 );
  background( 255 );
  fill( 128 );
  stroke( 0 );

  Table table = loadTable( "salaries.txt", "header, tsv" );

  for ( int idx = 0; idx < table.getRowCount (); ++idx ) {
    table.setFloat( idx, 4, 
    processDollars( table.getString( idx, "Salary" ) ) +
      processDollars( table.getString( idx, "Benefits" ) ) );
  }

  table.removeColumn( "Benefits" );

  float maxsal = 0;
  for ( int idx = 0; idx < table.getRowCount (); ++idx ) {
    float sal = table.getFloat( idx, 4 );
    maxsal = max( sal, maxsal );
  }
  // round maxsal up to the nearest 20K.
  maxsal = maxsal - (maxsal % 10000) + 10000;
  
  // Divide up the space of all salaries into 20K bins,
  // figure out how many bins are needed based on the max
  // salary.
  int bins = int( (maxsal-100000)/20000 );
  // Create an array of bins.
  int[] counts = new int[ bins ];

  // Walk over all salaries, incrementing the bin corresponding
  // to each salary.
  for ( int idx = 0; idx < table.getRowCount (); ++idx ) {
    float sal = table.getFloat( idx, 4 );
    int bidx = int( (sal - 100000) / 20000 );
    counts[bidx]++;
  }

  // Draw the histogram.
  int maxcount = max( counts );
  float w = (width - 100) / float( bins );

  for ( int idx = 0; idx < counts.length; ++idx ) {
    if ( counts[idx] > 0 ) {
      float h = map( counts[idx], 0, maxcount, 0, height - 100 );
      rect( 50 + w*idx, height-50-h, w, h );
    }
  }
}

