// A quick aggregate data visualization of all disclosed
// university employee salaries in Ontario.  Separate the
// data into four tiers: Assistant Professors, Associate
// Professors, Full Professors, and Others.

float processDollars( String val )
{
  // Break the dollar amount apart at all delimiters
  String[] digs = splitTokens( val, ",.$" );
  // Figure out the cents
  return float( join( digs, "" ) ) / 100.0;
}

void setup()
{
  size( 800, 400 );
  background( 255 );
  noStroke();
  
  Table table = loadTable( "salaries.txt", "header, tsv" );

  for( int idx = 0; idx < table.getRowCount(); ++idx ) {
    table.setFloat( idx, 4, 
      processDollars( table.getString( idx, "Salary" ) ) +
      processDollars( table.getString( idx, "Benefits" ) ) );
  }
  
  table.removeColumn( "Benefits" );
  
  float maxsal = 0;
  for( int idx = 0; idx < table.getRowCount(); ++idx ) {
    float sal = table.getFloat( idx, 4 );
    maxsal = max( sal, maxsal );
  }
  
  for( int idx = 0; idx < table.getRowCount(); ++idx ) {
    String pos = table.getString( idx, 3 ).toLowerCase();
    float sal = table.getFloat( idx, 4 );
    float x = map( sal, 100000, maxsal, 0, width );
    if( pos.contains( "professor" ) ) {
      if( pos.contains( "assistant" ) ) {
        fill( #00ff00, 50 );
        rect( x - 2, 300, 4, 100 );
      } else if( pos.contains( "associate" ) ) {
        fill( #0000ff, 50 );
        rect( x - 2, 200, 4, 100 );
      } else {
       fill( #ff0000, 50 );
        rect( x - 2, 100, 4, 100 );
      } 
    } else {
      fill( #808080, 50 );
      rect( x - 2, 000, 4, 100 );
    }
  }
}
